Gemeinde Adressverwaltung GUI: Gemeinde_Modelle.Gemeinde Klassenreferenz

Gemeinde Adressverwaltung GUI

Öffentliche Methoden | Statische öffentliche Attribute | Aufstellung aller Elemente
Gemeinde_Modelle.Gemeinde Klassenreferenz
Klassendiagramm für Gemeinde_Modelle.Gemeinde:
[Legende]
Zusammengehörigkeiten von Gemeinde_Modelle.Gemeinde:
[Legende]

## Öffentliche Methoden
def | __init__ (self, id=None, holen=False)
def | __str__ (self)

## Statische öffentliche Attribute
string | keyFeldNavi = 'id'

Die Dokumentation für diese Klasse wurde erzeugt aufgrund der Datei:

- Gemeinde_Modelle.py